/*
 * This file is part of WebLookAndFeel library.
 *
 * WebLookAndFeel library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * WebLookAndFeel library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WebLookAndFeel library.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.alee.laf.menu;

import com.alee.laf.WebLookAndFeel;
import com.alee.managers.language.LanguageManager;
import com.alee.managers.language.LanguageMethods;
import com.alee.managers.language.updaters.LanguageUpdater;
import com.alee.utils.ReflectUtils;

import javax.swing.*;
import java.awt.*;

/**
 * User: mgarin Date: 15.08.11 Time: 19:47
 */

public class WebMenu extends JMenu implements LanguageMethods
{
    private Point customMenuLocation = null;

    public WebMenu ()
    {
        super ();
    }

    public WebMenu ( String s )
    {
        super ( s );
    }

    public WebMenu ( Action a )
    {
        super ( a );
    }

    public WebMenu ( String s, boolean b )
    {
        super ( s, b );
    }

    public WebMenu ( String s, Icon icon )
    {
        super ( s );
        setIcon ( icon );
    }

    public void setMenuLocation ( int x, int y )
    {
        customMenuLocation = new Point ( x, y );
        if ( getPopupMenu ().isVisible () )
        {
            getPopupMenu ().setLocation ( x, y );
        }
    }

    public Point getCustomMenuLocation ()
    {
        return customMenuLocation;
    }

    public void setPopupMenuVisible ( boolean b )
    {
        boolean isVisible = isPopupMenuVisible ();
        if ( b != isVisible && ( isEnabled () || !b ) )
        {
            if ( b && isShowing () )
            {
                Point p = getCustomMenuLocation ();
                if ( p == null )
                {
                    p = getPopupMenuOrigin ();
                }
                getPopupMenu ().show ( this, p.x, p.y );
                //                getPopupMenu ().show ( this, WebMenu.this.getWidth (), 0 );
            }
            else
            {
                getPopupMenu ().setVisible ( false );
            }
        }
    }

    public WebMenuUI getWebUI ()
    {
        return ( WebMenuUI ) getUI ();
    }

    public void updateUI ()
    {
        if ( getUI () == null || !( getUI () instanceof WebMenuUI ) )
        {
            try
            {
                setUI ( ( WebMenuUI ) ReflectUtils.createInstance ( WebLookAndFeel.menuUI ) );
            }
            catch ( Throwable e )
            {
                e.printStackTrace ();
                setUI ( new WebMenuUI () );
            }
        }
        else
        {
            setUI ( getUI () );
        }
        if ( getPopupMenu () != null )
        {
            getPopupMenu ().updateUI ();
        }
    }

    /**
     * Language methods
     */

    public void setLanguage ( String key, Object... data )
    {
        LanguageManager.registerComponent ( this, key, data );
    }

    public void updateLanguage ( Object... data )
    {
        LanguageManager.updateComponent ( this, data );
    }

    public void updateLanguage ( String key, Object... data )
    {
        LanguageManager.updateComponent ( this, key, data );
    }

    public void removeLanguage ()
    {
        LanguageManager.unregisterComponent ( this );
    }

    public boolean isLanguageSet ()
    {
        return LanguageManager.isRegisteredComponent ( this );
    }

    public void setLanguageUpdater ( LanguageUpdater updater )
    {
        LanguageManager.registerLanguageUpdater ( this, updater );
    }

    public void removeLanguageUpdater ()
    {
        LanguageManager.unregisterLanguageUpdater ( this );
    }
}