/*
 * This file is part of WebLookAndFeel library.
 *
 * WebLookAndFeel library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * WebLookAndFeel library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WebLookAndFeel library.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.alee.laf.tabbedpane;

import com.alee.extended.painter.Painter;
import com.alee.laf.WebLookAndFeel;
import com.alee.utils.ReflectUtils;
import com.alee.utils.laf.ShapeProvider;

import javax.swing.*;
import java.awt.*;

/**
 * User: mgarin Date: 28.06.11 Time: 0:52
 */

public class WebTabbedPane extends JTabbedPane implements ShapeProvider
{
    public WebTabbedPane ()
    {
        super ();
    }

    public WebTabbedPane ( int tabPlacement )
    {
        super ( tabPlacement );
    }

    public WebTabbedPane ( int tabPlacement, int tabLayoutPolicy )
    {
        super ( tabPlacement, tabLayoutPolicy );
    }

    public int getRound ()
    {
        return getWebUI ().getRound ();
    }

    public void setRound ( int round )
    {
        getWebUI ().setRound ( round );
    }

    public int getShadeWidth ()
    {
        return getWebUI ().getShadeWidth ();
    }

    public void setShadeWidth ( int shadeWidth )
    {
        getWebUI ().setShadeWidth ( shadeWidth );
    }

    public Insets getContentInsets ()
    {
        return getWebUI ().getContentInsets ();
    }

    public void setContentInsets ( Insets contentInsets )
    {
        getWebUI ().setContentInsets ( contentInsets );
    }

    public Insets getTabInsets ()
    {
        return getWebUI ().getTabInsets ();
    }

    public void setTabInsets ( Insets tabInsets )
    {
        getWebUI ().setTabInsets ( tabInsets );
    }

    public Color getSelectedTopBg ()
    {
        return getWebUI ().getSelectedTopBg ();
    }

    public void setSelectedTopBg ( Color selectedTopBg )
    {
        getWebUI ().setSelectedTopBg ( selectedTopBg );
    }

    public Color getSelectedBottomBg ()
    {
        return getWebUI ().getSelectedBottomBg ();
    }

    public void setSelectedBottomBg ( Color selectedBottomBg )
    {
        getWebUI ().setSelectedBottomBg ( selectedBottomBg );
    }

    public Color getTopBg ()
    {
        return getWebUI ().getTopBg ();
    }

    public void setTopBg ( Color topBg )
    {
        getWebUI ().setTopBg ( topBg );
    }

    public Color getBottomBg ()
    {
        return getWebUI ().getBottomBg ();
    }

    public void setBottomBg ( Color bottomBg )
    {
        getWebUI ().setBottomBg ( bottomBg );
    }

    public void setSelectedForegroundAt ( int tabIndex, Color foreground )
    {
        getWebUI ().setSelectedForegroundAt ( tabIndex, foreground );
    }

    public Color getSelectedForegroundAt ( int tabIndex )
    {
        return getWebUI ().getSelectedForegroundAt ( tabIndex );
    }

    public void setBackgroundPainterAt ( int tabIndex, Painter painter )
    {
        getWebUI ().setBackgroundPainterAt ( tabIndex, painter );
    }

    public Painter getBackgroundPainterAt ( int tabIndex )
    {
        return getWebUI ().getBackgroundPainterAt ( tabIndex );
    }

    public TabbedPaneStyle getTabbedPaneStyle ()
    {
        return getWebUI ().getTabbedPaneStyle ();
    }

    public void setTabbedPaneStyle ( TabbedPaneStyle tabbedPaneStyle )
    {
        getWebUI ().setTabbedPaneStyle ( tabbedPaneStyle );
    }

    public Painter getPainter ()
    {
        return getWebUI ().getPainter ();
    }

    public void setPainter ( Painter painter )
    {
        getWebUI ().setPainter ( painter );
    }

    public int getTabRunIndent ()
    {
        return getWebUI ().getTabRunIndent ();
    }

    public void setTabRunIndent ( int tabRunIndent )
    {
        getWebUI ().setTabRunIndent ( tabRunIndent );
    }

    public int getTabOverlay ()
    {
        return getWebUI ().getTabOverlay ();
    }

    public void setTabOverlay ( int tabOverlay )
    {
        getWebUI ().setTabOverlay ( tabOverlay );
    }

    public TabStretchType getTabStretchType ()
    {
        return getWebUI ().getTabStretchType ();
    }

    public void setTabStretchType ( TabStretchType tabStretchType )
    {
        getWebUI ().setTabStretchType ( tabStretchType );
    }

    public Shape provideShape ()
    {
        return getWebUI ().provideShape ();
    }

    public WebTabbedPaneUI getWebUI ()
    {
        return ( WebTabbedPaneUI ) getUI ();
    }

    public void updateUI ()
    {
        if ( getUI () == null || !( getUI () instanceof WebTabbedPaneUI ) )
        {
            try
            {
                setUI ( ( WebTabbedPaneUI ) ReflectUtils.createInstance ( WebLookAndFeel.tabbedPaneUI ) );
            }
            catch ( Throwable e )
            {
                e.printStackTrace ();
                setUI ( new WebTabbedPaneUI () );
            }
        }
        else
        {
            setUI ( getUI () );
        }
    }
}
