/*
 * This file is part of WebLookAndFeel library.
 *
 * WebLookAndFeel library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * WebLookAndFeel library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WebLookAndFeel library.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.alee.managers.settings.processors;

import com.alee.managers.settings.SettingsProcessor;
import com.alee.managers.settings.SettingsProcessorData;

import javax.swing.*;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

/**
 * User: mgarin Date: 27.07.12 Time: 13:56
 */

public class AbstractButtonSettingsProcessor extends SettingsProcessor<AbstractButton, Boolean>
{
    private ItemListener itemListener;

    public AbstractButtonSettingsProcessor ( SettingsProcessorData data )
    {
        super ( data );
    }

    public Boolean getDefaultValue ()
    {
        Boolean defaultValue = super.getDefaultValue ();
        if ( defaultValue == null )
        {
            defaultValue = false;
        }
        return defaultValue;
    }

    protected void doInit ( AbstractButton abstractButton )
    {
        itemListener = new ItemListener ()
        {
            public void itemStateChanged ( ItemEvent e )
            {
                save ();
            }
        };
        abstractButton.addItemListener ( itemListener );
    }

    public void doDestroy ( AbstractButton abstractButton )
    {
        abstractButton.removeItemListener ( itemListener );
        itemListener = null;
    }

    public void doLoad ( AbstractButton abstractButton )
    {
        boolean newValue = loadValue ();
        if ( abstractButton.isSelected () != newValue )
        {
            abstractButton.setSelected ( newValue );
        }
    }

    public void doSave ( AbstractButton abstractButton )
    {
        saveValue ( abstractButton.isSelected () );
    }
}