/*
 * This file is part of WebLookAndFeel library.
 *
 * WebLookAndFeel library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * WebLookAndFeel library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WebLookAndFeel library.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.alee.managers.settings.processors;

import com.alee.extended.panel.CollapsiblePaneAdapter;
import com.alee.extended.panel.WebCollapsiblePane;
import com.alee.managers.settings.SettingsProcessor;
import com.alee.managers.settings.SettingsProcessorData;

/**
 * User: mgarin Date: 27.07.12 Time: 15:20
 */

public class WebCollapsiblePaneSettingsProcessor extends SettingsProcessor<WebCollapsiblePane, Boolean>
{
    private CollapsiblePaneAdapter collapsiblePaneAdapter;

    public WebCollapsiblePaneSettingsProcessor ( SettingsProcessorData data )
    {
        super ( data );
    }

    public Boolean getDefaultValue ()
    {
        Boolean defaultValue = super.getDefaultValue ();
        if ( defaultValue == null )
        {
            defaultValue = true;
        }
        return defaultValue;
    }

    protected void doInit ( WebCollapsiblePane collapsiblePane )
    {
        collapsiblePaneAdapter = new CollapsiblePaneAdapter ()
        {
            public void expanding ( WebCollapsiblePane pane )
            {
                save ();
            }

            public void collapsing ( WebCollapsiblePane pane )
            {
                save ();
            }
        };
        collapsiblePane.addCollapsiblePaneListener ( collapsiblePaneAdapter );
    }

    protected void doLoad ( WebCollapsiblePane collapsiblePane )
    {
        collapsiblePane.setExpanded ( loadValue () );
    }

    protected void doSave ( WebCollapsiblePane collapsiblePane )
    {
        saveValue ( collapsiblePane.isExpanded () );
    }

    protected void doDestroy ( WebCollapsiblePane collapsiblePane )
    {
        collapsiblePane.removeCollapsiblePaneListener ( collapsiblePaneAdapter );
        collapsiblePaneAdapter = null;
    }
}