/*
 * This file is part of WebLookAndFeel library.
 *
 * WebLookAndFeel library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * WebLookAndFeel library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WebLookAndFeel library.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.alee.managers.settings.processors;

import com.alee.extended.date.DateSelectionListener;
import com.alee.extended.date.WebDateField;
import com.alee.managers.settings.SettingsProcessor;
import com.alee.managers.settings.SettingsProcessorData;

import java.util.Date;

/**
 * User: mgarin Date: 29.11.12 Time: 13:23
 */

public class WebDateFieldSettingsProcessor extends SettingsProcessor<WebDateField, Date>
{
    private DateSelectionListener selectionListener;

    public WebDateFieldSettingsProcessor ( SettingsProcessorData data )
    {
        super ( data );
    }

    protected void doInit ( WebDateField dateField )
    {
        selectionListener = new DateSelectionListener ()
        {
            public void dateSelected ( Date date )
            {
                save ();
            }
        };
        dateField.addDateSelectionListener ( selectionListener );
    }

    protected void doLoad ( WebDateField dateField )
    {
        dateField.setDate ( loadValue () );
    }

    protected void doSave ( WebDateField dateField )
    {
        saveValue ( dateField.getDate () );
    }

    protected void doDestroy ( WebDateField dateField )
    {
        dateField.removeDateSelectionListener ( selectionListener );
        selectionListener = null;
    }
}