/*
 * This file is part of WebLookAndFeel library.
 *
 * WebLookAndFeel library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * WebLookAndFeel library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WebLookAndFeel library.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.alee.managers.settings.processors;

import com.alee.extended.colorchooser.GradientData;
import com.alee.extended.colorchooser.WebGradientColorChooser;
import com.alee.managers.settings.SettingsProcessor;
import com.alee.managers.settings.SettingsProcessorData;

import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

/**
 * User: mgarin Date: 28.11.12 Time: 15:06
 */

public class WebGradientColorChooserSettingsProcessor extends SettingsProcessor<WebGradientColorChooser, GradientData>
{
    private ChangeListener changeListener;

    public WebGradientColorChooserSettingsProcessor ( SettingsProcessorData data )
    {
        super ( data );
    }

    protected void doInit ( WebGradientColorChooser gradientColorChooser )
    {
        changeListener = new ChangeListener ()
        {
            public void stateChanged ( ChangeEvent e )
            {
                save ();
            }
        };
        gradientColorChooser.addChangeListener ( changeListener );
    }

    protected void doLoad ( WebGradientColorChooser gradientColorChooser )
    {
        gradientColorChooser.setGradientData ( loadValue () );
    }

    protected void doSave ( WebGradientColorChooser gradientColorChooser )
    {
        saveValue ( gradientColorChooser.getGradientData () );
    }

    protected void doDestroy ( WebGradientColorChooser gradientColorChooser )
    {
        gradientColorChooser.removeChangeListener ( changeListener );
        changeListener = null;
    }
}