/*
 * This file is part of WebLookAndFeel library.
 *
 * WebLookAndFeel library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * WebLookAndFeel library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WebLookAndFeel library.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.alee.managers.settings.processors;

import com.alee.managers.settings.SettingsProcessor;
import com.alee.managers.settings.SettingsProcessorData;
import com.alee.utils.CompareUtils;

import java.awt.*;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;

/**
 * User: mgarin Date: 27.07.12 Time: 15:23
 */

// todo Save window normal/maximized window states, iconified should be converted into normal
public class WindowSettingsProcessor extends SettingsProcessor<Window, Rectangle>
{
    private ComponentAdapter componentAdapter;

    public WindowSettingsProcessor ( SettingsProcessorData data )
    {
        super ( data );
    }

    protected void doInit ( Window window )
    {
        componentAdapter = new ComponentAdapter ()
        {
            public void componentResized ( ComponentEvent e )
            {
                save ();
            }

            public void componentMoved ( ComponentEvent e )
            {
                save ();
            }
        };
        window.addComponentListener ( componentAdapter );
    }

    protected void doLoad ( Window window )
    {
        Rectangle bounds = loadValue ();
        if ( bounds == null )
        {
            window.pack ();
            window.setLocationRelativeTo ( null );
        }
        else if ( CompareUtils.equals ( bounds, window.getBounds () ) )
        {
            Dimension size = bounds.getSize ();
            if ( size.width > 0 && size.height > 0 )
            {
                window.setSize ( size );
            }
            else
            {
                window.pack ();
            }

            Point location = bounds.getLocation ();
            if ( location.x > 0 && location.y > 0 )
            {
                window.setLocation ( location );
            }
            else
            {
                window.setLocationRelativeTo ( null );
            }
        }
    }

    protected void doSave ( Window window )
    {
        saveValue ( window.getBounds () );
    }

    protected void doDestroy ( Window window )
    {
        window.removeComponentListener ( componentAdapter );
        componentAdapter = null;
    }
}