/*
* This file is part of WebLookAndFeel library.
*
* WebLookAndFeel library is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* WebLookAndFeel library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with WebLookAndFeel library.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.alee.utils;

import java.util.HashMap;
import java.util.Map;

/**
 * This class provides a set of utilities to work with various maps.
 *
 * @author Mikle Garin
 * @since 1.3
 */

public class MapUtils
{
    /**
     * Returns cloned HashMap.
     *
     * @param map HashMap to clone
     * @param <K> HashMap key type
     * @param <V> HashMap value type
     * @return cloned HashMap
     */
    public static <K, V> HashMap<K, V> cloneHashMap ( HashMap<K, V> map )
    {
        HashMap<K, V> clone = new HashMap<K, V> ();
        for ( Map.Entry<K, V> entry : map.entrySet () )
        {
            clone.put ( entry.getKey (), entry.getValue () );
        }
        return clone;
    }

    /**
     * Returns cloned Map.
     *
     * @param map Map to clone
     * @param <K> Map key type
     * @param <V> Map value type
     * @return cloned Map
     */
    public static <K, V> Map<K, V> cloneMap ( Map<K, V> map )
    {
        Map<K, V> clone = new HashMap<K, V> ();
        for ( Map.Entry<K, V> entry : map.entrySet () )
        {
            clone.put ( entry.getKey (), entry.getValue () );
        }
        return clone;
    }
}